@@ -59,10 +59,9 @@ sub _build_req_content {
 sub request {
   my $self = shift;
   my $content = $self->_build_req_content;
-  my $servers = SERVERS;
   my $action_url = 'https://www.thepaymentgateway.net/';
   my $ua = $self->_user_agent;
-  my $req = HTTP::Request->new(POST => shift @$servers);
+  my $req = HTTP::Request->new(POST => SERVERS->[0]);
   $req->content_type('text/xml; charset=UTF-8');
   $req->header('SOAPAction' => $action_url . $self->_type);
   $req->content($content);
@@ -72,7 +71,7 @@ sub request {
   if ($res->is_success) {
     return $self->parse_response($res->content);
   } else {
-    $req->uri(shift @$servers);
+    $req->uri(SERVERS->[1]);
     $res = $ua->request($req);
 
     if ($res->is_success && $res->content) {
